pub struct AnimatedRenderedDecoder {
pub default_color: [u8; 4],
pub font_size_px: f32,
pub side_margin_px: u32,
pub bottom_margin_px: u32,
/* private fields */
}Expand description
Animated subtitle decoder. See module docs.
Fields
default_color: [u8; 4]Default text colour when no \c override is active.
font_size_px: f32Nominal font size in pixels passed to the shaper.
side_margin_px: u32Pixel margin between the canvas edge and the text bounding box.
bottom_margin_px: u32Pixel margin between the canvas bottom and the lowest baseline.
Implementations
Sourceimpl AnimatedRenderedDecoder
impl AnimatedRenderedDecoder
Sourcepub fn new(
inner: Box<dyn Decoder>,
width: u32,
height: u32,
face: FaceChain,
) -> Self
pub fn new( inner: Box<dyn Decoder>, width: u32, height: u32, face: FaceChain, ) -> Self
Build a new AnimatedRenderedDecoder wrapping inner and
rendering at width × height using face.
Sourcepub fn set_offset_ms(&mut self, offset_ms: i32)
pub fn set_offset_ms(&mut self, offset_ms: i32)
Set the cue-relative time at which the next receive_frame
call will sample the animation. Subsequent calls keep this
offset until it’s changed.